submodules = [
    "babel",
    "charset_normalizer",
    "datautil",
    "myst-parser",
    "sphinx",
    "sphinx-intl",
    "sphinxemoji",
    "markdown",
    "markdown-it",
    "linkify-it",
    "mdit_py_plugins",
    "myst_parser",
    "openpyxl",
    "pygments",
    "snowballstemmer",
    "alabaster",
    "sphinx_bootstrap_theme",
    "sphinx_rtd_theme",
    "mkdocs_material",
    "lunr",
    # "sphinx_needs",  ## exclude
]
hiddenimports = [
    "certifi",
    "click",
    "idna",
    "inspect",
    "locale",
    "pkg_resources",
    "importlib_metadata",
    "markupsafe",
    "pytz",
    "pyrsistent",
    "yaml",
    "materialx",
    "material",
    "pymdownx",
    "mkdocsplantuml",
    "mkdocs_alabaster",
    "mkdocs_badges",
    "mkdocs_coverage",
    "j2cli",
    "jinja2",
    "ghp_import",
]
collect_all = [
    "docutils",
    "mkdocs",
    "mkdocs_custommill",
    "sphinx",
]
metadata = [
    "Babel",
    "markdown",
    "mkdocs",
    "mkdocs_alabaster",
    "mkdocs_material",
    "mkdocs_plantuml",
    "mkdocs_badges",
    "mkdocs_coverage",
    "alabaster",
    "sphinx_bootstrap_theme",
]
package_data = [
    "babel",
    "certifi",
    "charset_normalizer",
    "jsonschema",
    "pytz",
    "markdown_it",
    "mdit_py_plugins",
    "alabaster",
    "mkdocs_alabaster",
    "mkdocs_badges",
    "sphinx_bootstrap_theme",
    "sphinx_rtd_theme",
    "material",
    "pygments_style_kit",
    "sphinxcontrib"
    # "sphinx_needs",
]
excludes = [
    'sphinx.testing',
    'sphinx.testing.comparer',
    'sphinx.testing.fixtures',
    'sphinx.testing.path',
    'sphinx.testing.restructuredtext',
    'sphinx.testing.util',
    'mkdocs.tests',
    'mkdocs.tests.base',
    'mkdocs.tests.build_tests',
    'mkdocs.tests.cli_tests',
    'mkdocs.tests.config',
    'mkdocs.tests.config.base_tests',
    'mkdocs.tests.config.config_options_legacy_tests',
    'mkdocs.tests.config.config_options_tests',
    'mkdocs.tests.config.config_tests',
    'mkdocs.tests.gh_deploy_tests',
    'mkdocs.tests.integration',
    'mkdocs.tests.livereload_tests',
    'mkdocs.tests.localization_tests',
    'mkdocs.tests.new_tests',
    'mkdocs.tests.plugin_tests',
    'mkdocs.tests.search_tests',
    'mkdocs.tests.structure',
    'mkdocs.tests.structure.file_tests',
    'mkdocs.tests.structure.nav_tests',
    'mkdocs.tests.structure.page_tests',
    'mkdocs.tests.structure.toc_tests',
    'mkdocs.tests.theme_tests',
    'mkdocs.tests.utils',
    'mkdocs.tests.utils.babel_stub_tests',
    'mkdocs.tests.utils.utils_tests',
    'numpy',
    'six',
    'toml',
    'unittest',
    'email',
    'setuptools',
    'distutils',
    'pygls',
    'matplotlib',
    'pyparsing',
    'PIL',
]